<?xml version="1.0"?> 

<!--
Chrysalis Web Framework [http://chrysalis.sourceforge.net]
Copyright (c) 2002, 2003, 2004, Paul Strack

All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this
list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice,
this list of conditions and the following disclaimer in the documentation
and/or other materials provided with the distribution.

3. Neither the name of the copyright holder nor the names of its contributors
may be used to endorse or promote products derived from this software without
specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
                xmlns="http://www.w3.org/1999/xhtml">
  <xsl:output method="xml"/>

  <xsl:template match="DTD">
    <html>
      <head>
        <title><xsl:value-of select="normalize-space(comment()[1])"/></title>
      </head>

      <body>
        <h2><xsl:value-of select="@NAME" /> Documentation</h2>
        <p><xsl:apply-templates select="comment()[2]"/></p>
        <p>Attributes whose names are in <i>italics</i> are optional.</p>
        <table border="1" cellspacing="0" cellpadding="3">
          <tr><th>Tag</th><th>Summary</th></tr>
          <xsl:apply-templates select="ELEMENT" mode="toc">
            <xsl:sort select="@NAME"/> 
          </xsl:apply-templates>
        </table>
        <xsl:apply-templates select="ELEMENT"/>
      </body>
  
     </html>
  </xsl:template>

  <xsl:template match="ELEMENT" mode="toc">
    <xsl:variable name="comment" select="preceding-sibling::comment()[1]"/>
    <tr>
      <td><a href="#{@NAME}"><xsl:value-of select="@NAME"/></a></td>
      <td><xsl:value-of select="substring-before($comment, '.')" />.</td>
    </tr>
  </xsl:template>

  <xsl:template match="ELEMENT">
    <xsl:variable name="name" select="@NAME" />
    <a name="{@NAME}"></a><h3><xsl:value-of select="$name" /></h3>
    <p><xsl:apply-templates select="preceding-sibling::comment()[1]"/></p>
    <xsl:if test="//ELEMENT[SUBELEMENT/@NAME=$name]">
      <p><b>Used in: </b>
        <xsl:for-each select="//ELEMENT[SUBELEMENT/@NAME=$name]">
          <a href="#{@NAME}"><xsl:value-of select="@NAME"/></a>
          <xsl:if test="position() != last()">, </xsl:if>
        </xsl:for-each>
      </p>
    </xsl:if>
    <p>
      <b>Content: </b>
      <xsl:choose>
        <xsl:when test="EMPTY">Empty</xsl:when>
        <xsl:when test="TEXT">Text</xsl:when>
        <xsl:otherwise>
          (<xsl:for-each select="SUBELEMENT">
             <a href="#{@NAME}"><xsl:value-of select="@NAME"/></a>
             <xsl:value-of select="@MULTIPLICITY"/>
             <xsl:if test="position() &lt; last()">, </xsl:if>
           </xsl:for-each>)
        </xsl:otherwise>
      </xsl:choose>
      <xsl:value-of select="text()"/>
    </p>
    <xsl:if test="../ATTRIBUTE[@ELEMENT=$name]">
      <p><b>Attributes</b></p>
      <ul>
        <xsl:apply-templates select="../ATTRIBUTE[@ELEMENT=$name]" />
      </ul>
    </xsl:if>
  </xsl:template>

  <xsl:template match="ATTRIBUTE">
    <li>
      <xsl:if test="@REQUIRED='#IMPLIED'">
        <b><i><xsl:value-of select="@NAME" /></i></b> 
      </xsl:if>
      <xsl:if test="not(@REQUIRED='#IMPLIED')">
        <b><xsl:value-of select="@NAME" /></b> 
      </xsl:if>
      [<xsl:value-of select="@CONTENT" />]:
      <xsl:apply-templates select="preceding-sibling::comment()[1]"/>
    </li>
  </xsl:template>

  <xsl:template match="comment()"> 
    <xsl:value-of select="." disable-output-escaping="yes"/>
  </xsl:template>
</xsl:stylesheet>